<?php
/**
 * AJAX Functions, GDocs Wordpress plugin
 *
 * This file contains all the ajax functions required to process AJAX requests
 * Accessed by user from post/page edit form
 * Returns value to browser via http headers
 *
 * @author Lim Jiunn Haur <fisherman.jiang@broken-watch.info>
 * @copyright Copyright (c) 2008, Lim Jiunn Haur
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * @package gdocs
 * @since 0.5
 */

/**
 * Load necessary Wordpress files to use standard functions
 */
require_once ('../../../wp-config.php');
require_once ('../../../wp-includes/wp-db.php');
require_once ('../../../wp-includes/formatting.php');

##################### BEGIN Global Execution Space ################################

/**
 * Data regarding current user
 * @global mixed $GLOBALS['userdata']
 * @name $userdata
 */
global $userdata;
get_currentuserinfo();

if ($userdata->user_level < 8){
	// insufficient rights
	header ('HTTP/1.0 403 Forbidden');
	echo "You do not have sufficient access rights.";
	return NULL;
}

// check if action is set
$action = NULL;
if (isset($_GET['action'])){
	$action = $_GET['action'];
	// execute
	$func = 'gdocs_' . $action;
	try {
		$func ();
	}catch (Exception $e){
		header ('HTTP/1.0 400 Bad Request');
		echo "An error has occurred while trying to update the list of Google Documents and Spreadsheets." . PHP_EOL;
		echo "Error Message: " . $e->getMessage();
	}
}else {
	// missing paramter
	header ('HTTP/1.0 400 Bad Request');
	echo "Required parameters missing.";
	return NULL;
}

##################### END Global Execution Space ##################################
 
/**
 * Update list of Google Documents and Spreadsheets
 * 
 * Connects to Google and retrieves list of documents and spreadsheets
 * Updates table in Wordpress database
 * Returns data to browser in a JSON variable via http headers
 */
function gdocs_update_list (){
	
	// get Google Documents client
	$gdClient = GClient::getInstance('Doc');
	
	// initialize collector stack
	$docs = array();
	
	// update document list
	gdocs_update_documents ($gdClient, &$docs);
	
	// get Google Spreadsheets client
	$gsClient = GClient::getInstance('St');
		
	// update spreadsheet list
	gdocs_update_sts ($gdClient, $gsClient, &$docs);
	
	// update DB
	GDB::write ($docs);
	
	// return json data
	header('X-JSON: (' . json_encode ($docs) . ')');
	
}

/**
 * Retrieve document list
 */
function gdocs_update_documents ($gdClient, $docs){

	// get documents feed
	$feed = $gdClient->getDocFeed ();
	
	foreach ($feed as $entry){
		
		// push to stack
		$docs[] = $entry;
		
	}
	
}

/**
 * Retrieve spreadsheet list
 */
function gdocs_update_sts ($gdClient, $gsClient, $docs){

	// get spreadsheets feed
	$feed = $gdClient->getStFeed ();
	
	foreach ($feed as $entry){
		
		// get worksheets feed
		$wtFeed = $gsClient->getWtFeed ($entry->main_id);
				
		if ($wtFeed) foreach ($wtFeed->entries as $wtEntry){
		
			// extract worksheet id
			$wtId = split ('/', $wtEntry->getId()->getText());
			$entry->sub_id = $wtId[8];
			
			// push to stack
			$docs[] = clone $entry;
			
		}
	
	}
}

?>
