<?php
/*
Plugin Name: Inline Google Docs
Plugin URI: http://wordpress.org/extend/plugins/inline-google-docs/
Description: Inline Google Docs allows the user to display contents of his google docs on his pages/posts, using shortcode for markup. Requires PHP 5.
Version: 0.5.1
Author: Lim Jiunn Haur
Author URI: http://broken-watch.info/
*/

/*  Copyright 2008  Lim Jiunn Haur  (email : fisherman.jiang@broken-watch.info)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
 * Main execution file, GDocs Wordpress plugin
 *
 * This file contains all the hooks and actions required for the abovementioned plugin.
 * Includes:
 * - activation and deactivation handlers
 * - shortcode handler
 * - options (plugin configuration) page handler
 *
 * @author Lim Jiunn Haur <fisherman.jiang@broken-watch.info>
 * @copyright Copyright (c) 2008, Lim Jiunn Haur
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * @version 0.5
 * @package gdocs
 * @todo Long term todo list
 * - Spreadsheet forms
 * - test IE
 * - Google Charts
 * - Google Visualizations
 * - Google Gadgets
 */

// add Zend library to path
$path = dirname (__FILE__) . "/library";
set_include_path (get_include_path () . PATH_SEPARATOR . $path);

/**
 * Load the Zend library to use classes from the Zend_Gdata and Zend_Http packages
 *
 * @link http://framework.zend.com/apidoc/core/
 */
require_once ('Zend/Loader.php');
Zend_Loader::loadClass ('Zend_Http_Client');
/*Zend_Loader::loadClass ('Zend_Http_Client_Adapter_Proxy');
Zend_Loader::loadClass ('Zend_Http_Client_Adapter_Exception');*/
Zend_Loader::loadClass ('Zend_Gdata');
/*Zend_Loader::loadClass ('Zend_Gdata_App');
Zend_Loader::loadClass ('Zend_Gdata_App_AuthException');*/
Zend_Loader::loadClass ('Zend_Gdata_ClientLogin');
Zend_Loader::loadClass ('Zend_Gdata_Docs');
Zend_Loader::loadClass ('Zend_Gdata_Spreadsheets');
/*Zend_Loader::loadClass ('Zend_Gdata_Spreadsheets_ListFeed');*/
Zend_Loader::loadClass ('Zend_Gdata_Spreadsheets_DocumentQuery');

// load all other gdocs classes
require_once ('inc/gclient.php');
require_once ('inc/gcache.php');
require_once ('inc/gdb.php');
require_once ('inc/gdisplay.php');
require_once ('inc/gfeed.php');

/**
 * Shortcode handler
 *
 * Determines if the gdoc is a spreadsheet or a document
 * Calls the corresponding display functions
 * @param array $atts contains attributes given by user in shortcode
 * @param string $content the raw string enclosed by the shortcode tags (optional, ignored)
 * @return string html-formatted contents of the gdoc to be displayed in place of the shortcode
 */
function gdocs_display ($atts, $content=NULL){

	// check parameter exists
	if (is_null ($atts['type'])) return NULL;
	
	try {
		// e.g. gdocs_display_document ($atts);
		$func = 'gdocs_display_' . $atts['type'];
		return $func ($atts);
		
	} catch (Exception $e) {
		// any error at all
		return NULL;
	}
	
}

/**
 * Secondary shortcode handler
 *
 * Retrieves and formats contents of the Google Document
 * Keeps a copy in cache
 * @param array $atts contains attributes given by user in shortcode
 * @return html-formatted contents of the Google Document
 */
function gdocs_display_document ($atts){

	// check parameter exists
	if (is_null ($atts['id'])) return NULL;
	
	// try cache
	$cache_session = new GCache ($atts['id']);
	if ($cache_session->read ($html)) return $html;
	
	// get Http client
	$gClient = GClient::getInstance ('Raw', $atts);
	
	// connect to Google, get feed, markup
	$html = "<div class='gdocs' id='gdocs_{$atts['id']}'>" . $gClient->getFeed() . "</div>";
	
	// keep a copy in cache
	$cache_session->write ($html);
	
	// display
	return $html;
	
}

/**
 * Secondary shortcode handler
 *
 * Retrieves and formats contents of the Google Spreadsheet
 * Keeps a copy in cache
 * @param array $atts contains attributes given by user in shortcode
 * @return html-formatted contents of the Google Spreadsheet
 */
function gdocs_display_spreadsheet ($atts){

	// check parameters exist
	if (is_null ($atts['wt_id']) || is_null ($atts['st_id'])) return NULL;
	
	// print stylesheet <link>
	isset ($atts['style']) ? $html = GDisplay::printStylesheet ($atts['style']) : NULL;
	
	// try cache, retrieve table
	$cache_session = new GCache ($atts['st_id'], $atts['wt_id']);
	if ($cache_session->read ($tbl)){
		$html .= $tbl;
		return $html;
	}

	// get GData client
	$gsClient = GClient::getInstance ('St');
	
	// get list feed
	$feed = $gsClient->getLtFeed($atts['st_id'], $atts['wt_id']);
	if (!$feed) return NULL;
	
	// format
	$tbl = GDisplay::printStTbl ($feed, $atts['st_id'], $atts['wt_id'], $atts['style'], $atts['headings']);
	
	// keep a copy in cache
	$cache_session->write ($tbl);
	
	$html .= $tbl;
	
	// display
	return $html;

}

/**
 * Hook for options page
 */
function gdocs_options (){

	if (function_exists ('add_options_page')){
		// add an options page that is printed by gdocs_options_setup
		add_options_page ('Inline Google Docs', 'G Docs', 'manage_options', basename(__FILE__), 'gdocs_options_setup');
		
	} 

}

/**
 * Setup and print options page
 */
function gdocs_options_setup (){

	GDisplay::printHead ();
	GDisplay::printLogin ();
	GDisplay::printProxy ();
	GDisplay::printCache ();

	try {
		
		// get Google Docs client, login
		$gdClient = GClient::getInstance('Doc');
		
		// list of documents
		$docs = array();
		
		GDisplay::printDocs ($gdClient, $docs);
		
		// get Google Spreasheets client
		$gsClient = GClient::getInstance('St');
		
		GDisplay::printSts ($gdClient, $gsClient, $docs);
		
		// update DB with list of docs/spreadsheets
		GDB::write ($docs);
		
	} catch (Zend_Http_Client_Adapter_Exception $e){
		// connnection problem 
		GDisplay::printConnError ();
	} catch (Zend_Gdata_App_AuthException $e) {
	
		// google docs login problem
		if (!get_option ('gdocs_user') || !get_option ('gdocs_pwd')){ 
			GDisplay::printNoLoginError ();
		}else { 
			GDisplay::printWrongLoginError ();
		}
		
	} catch (Exception $e){
		GDisplay::printError ();
	} 
	
	GDisplay::printFoot ();

}

/**
 * Install plugin
 *
 * Adds configuration options
 * Creates table in Wordpress database
 */
function gdocs_install (){
	
	// login credentials
	add_option ('gdocs_user');
	add_option ('gdocs_pwd');
	
	// proxy config
	add_option ('gdocs_proxy_host');
	add_option ('gdocs_proxy_port');
	add_option ('gdocs_proxy_user');
	add_option ('gdocs_proxy_pwd');
	
	// cache config
	add_option ('gdocs_cache_expiry');
	
	// create table in DB to store shortcode tags
	GDB::create ();
}

/**
 * Uninstall plugin
 *
 * Removes configuration options
 * Drops table from Wordpress database
 */
function gdocs_uninstall (){

	delete_option ('gdocs_user');
	delete_option ('gdocs_pwd');
	delete_option ('gdocs_proxy_host');
	delete_option ('gdocs_proxy_port');
	delete_option ('gdocs_proxy_user');
	delete_option ('gdocs_proxy_pwd');
	delete_option ('gdocs_cache_expiry');
	
	// remove table from DB
	GDB::drop ();
}

######################## BEGIN Global Execution Space ################################

// add actions
add_action ('admin_menu', 'gdocs_options');
add_action ('edit_form_advanced', array('GDisplay', 'printHelper'), 1);
add_action ('edit_page_form', array('GDisplay', 'printHelper'), 1);

// add shortcode
add_shortcode ('gdocs', 'gdocs_display');

// add installation hooks
register_activation_hook (__FILE__, 'gdocs_install');
register_deactivation_hook (__FILE__, 'gdocs_uninstall');

// add javascript (gdocs.js, prototype)
global $pagenow;
$wp_pages = array ('post.php', 'post-new.php', 'page.php', 'page-new.php');
if (in_array ($pagenow, $wp_pages)){
	wp_enqueue_script ('gdocs', '/wp-content/plugins/gdocs/inc/gdocs.js.php?url=' . get_bloginfo ('url'), array ('prototype'));
}

######################## END Global Execution Space ##################################

?>