<?php
/**
 * DB class, GDocs Wordpress plugin
 *
 * Handles DB access
 *
 * @author Lim Jiunn Haur <fisherman.jiang@broken-watch.info>
 * @copyright Copyright (c) 2008, Lim Jiunn Haur
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * @package gdocs
 * @since 0.5
 */
 
/**
 * GDB class
 * @subpackage inc
 */
class GDB {

	/**#@+
	 * @access public
	 * @static
	 */
	 
	/**
	 * Creates table in DB
	 */
	public static function create (){
		// DB interface
		global $wpdb;
		
		$tbl = $wpdb->prefix . "gdocs";
		
		// check if table exists
		if($wpdb->get_var("show tables like '$tbl'") != $tbl) {
			
			// create GDOCS (id, title, type, main_id, sub_id)
			$sql = "CREATE TABLE " . $tbl . " (
				title TINYTEXT NOT NULL,
				type ENUM('document', 'spreadsheet') NOT NULL DEFAULT 'document',
				main_id VARCHAR(50) NOT NULL,
				sub_id VARCHAR(50) NULL,
				INDEX(type),
				PRIMARY KEY(main_id, sub_id)
			) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
			
			require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			dbDelta($sql);
	
			$wpdb->query ($sql);
			
		}
	}
	
	/**
	 * Drops table
	 */
	public static function drop (){
		global $wpdb;
		$wpdb->query ("DROP TABLE IF EXISTS " . $wpdb->prefix . "gdocs");
	}

	/**
	 * Reads data from database
	 * @return mixed $results data read from database
	 */
	public static function read (){
	
		global $wpdb;
		
		// retrieve list of documents and spreadsheets from DB
		$results = $wpdb->get_results ("SELECT * FROM {$wpdb->prefix}gdocs", 'OBJECT');
		
		return $results;
		
	}
	
	/**
	 * Writes data to database
	 * @param $dataArr array of data to write to database
	 */
	public static function write ($dataArr){
	
		// if no data, stop here	
		if (is_null($dataArr[0])) return;
	
		global $wpdb;
		
		// clear table
		$wpdb->query ("TRUNCATE TABLE {$wpdb->prefix}gdocs");
		
		$query = "INSERT INTO {$wpdb->prefix}gdocs (title, type, main_id, sub_id) VALUES ";
		
		// INSERT INTO tbl VALUES (...), (...), (...)
		foreach ($dataArr as $data){
			$sub_id = isset ($data->sub_id) ? $wpdb->escape ($data->sub_id) : NULL; // documents don't have sub_id
			$query .= "
				('" . 
				$wpdb->escape ($data->title) . "', '" .
				$data->type . "', '".  // don't worry, this is safe
				$wpdb->escape ($data->main_id) . "', '" . 
				$sub_id . "'),";
		}
		
		// remove last comma
		$query = substr ($query, 0, strlen ($query)-1);
		
		$wpdb->query ($query);
	
	}
	
	/**#@-*/

}

?>