<?php
/**
 * Display class, GDocs Wordpress plugin
 *
 * Handles HTML formatting
 *
 * @author Lim Jiunn Haur <fisherman.jiang@broken-watch.info>
 * @copyright Copyright (c) 2008, Lim Jiunn Haur
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * @package gdocs
 * @since 0.5
 */
 
/**
 * GDisplay class
 *
 * No special OOP techniques used here
 * Groups all display-related functions together
 * @subpackage inc
 */
class GDisplay {
	
	/**
	 * Stylesheets on this page
	 *
	 * Keeps a record so that any given stylesheet
	 * isn't imported more than once on the same page
	 * @access private
	 * @var array
	 * @static
	 */
	private static $stylesheets = array ();

	/**#@+
	 * @access public
	 * @static
	 */
	 
	/**
	 * Prints head of configuration page
	 */
	public static function printHead (){
	?>
	
	<div class='wrap'>
		<h2>Inline Google Docs</h2>
		<form method='post' action='options.php'>
			<?php wp_nonce_field ('update-options'); ?>
			
	<?php
	
	}

	/**
	 * Prints login credentials input form
	 */
	public static function printLogin (){
	?>
	
			<!-- Login Credentials -->
			<h3>Google Account Login</h3>
			<table cellpadding="2" cellspacing="5">
				<tbody>
					<tr valign="top">
						<th scope="row">Username:</th>
						<td><input type="text" size="40" name="gdocs_user" value="<?php echo get_option ('gdocs_user'); ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row">Password:</th>
						<td><input type="password" size="40" name="gdocs_pwd" value="<?php echo get_option ('gdocs_pwd'); ?>" /></td>
					</tr>
				</tbody>
			</table>
	
	<?php
	}
	
	/**
	 * Prints proxy settings input form
	 */
	public static function printProxy (){
	?>
	
			<!-- Proxy Settings -->
			<h3>Proxy Settings</h3>
			<table cellpadding="2" cellspacing="5">
				<tbody>
					<tr valign="top">
						<th scope="row">Host:</th>
						<td><input type="text" size"40" name="gdocs_proxy_host" value="<?php echo get_option ('gdocs_proxy_host'); ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row">Port:</th>
						<td><input type="text" size"40" name="gdocs_proxy_port" value="<?php echo get_option ('gdocs_proxy_port'); ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row">Username:</th>
						<td><input type="text" size"40" name="gdocs_proxy_user" value="<?php echo get_option ('gdocs_proxy_user'); ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row">Password:</th>
						<td><input type="password" size"40" name="gdocs_proxy_pwd" value="<?php echo get_option ('gdocs_proxy_pwd'); ?>" /></td>
					</tr>
				</tbody>
			</table>
	
	<?php
	}
	
	/**
	 * Prints cache settings input form
	 */
	public static function printCache (){
	?>
	
			<!-- Cache Settings -->
			<h3>Cache Settings</h3>
			<small>Set to <span style="color: blue">'0'</span> to turn caching off.</small>
			<table cellpadding="2" cellspacing="5">
				<tbody>
					<tr valign="top">
						<th scope="row">Lifespan:</th>
						<td><input type="text" size"40" name="gdocs_cache_expiry" value="<?php echo get_option ('gdocs_cache_expiry'); ?>" /> minutes</td>
					</tr>
				</tbody>
			</table>
	
	<?php
	}
	
	/**
	 * Prints list of documents
	 * @param $gdClient Google API (GData_Docs) client
	 * @param $docs collects document data to write to DB
	 */
	public static function printDocs ($gdClient, &$docs) {
	
		// get documents feed
		$feed = $gdClient->getDocFeed ();
	
	?>		
			<!-- Document List -->
			<h3>Google Documents</h3>
			<small>Use the corresponding Document ID in your shortcode.<br />
			<span style="color: blue">[gdocs id=<em>doc_id</em> type='document']</span>.</small>
			<table cellpadding="2" cellspacing="5">
				<thead style="text-align:left">
					<tr><th>Title</th><th>Document ID</th></tr>
				</thead>
				<tbody>
	
	<?php
			
		foreach ($feed as $entry){
	?>
				<tr><td><?php echo $entry->title; ?></td><td><?php
				
				echo $entry->main_id;
				
				// push to stack
				$docs[] = $entry;
				
	?></td></tr>
	
	<?php 
		} 
	?>
			</tbody>
			</table>

	<?php
	
	}
	
	/**
	 * Prints list of spreadsheets
	 * @param $gdClient Google API (Gdata_Docs) client
	 * @param $gsClient Google API (Gdata_Spreadsheets) client
	 * @param $docs collects spreadsheet data to write to DB
	 */
	public static function printSts ($gdClient, $gsClient, &$docs){
	
		// get spreadsheets feed
		$feed = $gdClient->getStFeed ();
		
	?>
		<!-- Spreadsheet List -->
			<h3>Google Spreadsheets</h3>
			<small>Use the corresponding Spreadsheet ID and Worksheet ID in your shortcode.<br />
			<span style="color: blue">[gdocs st_id=<em>spreadsheet_id</em> wt_id=<em>worksheet_id</em> type='spreadsheet']</span>.</small>
	
			<table cellpadding="2" cellspacing="5">
				<thead style="text-align:left">
					<tr><th>Title</th><th>Spreadsheet ID</th><th>Worksheets</th></tr>
				</thead>
				<tbody>
	<?php
		
		foreach ($feed as $entry){
	?>
				<tr><td><?php echo $entry->title; ?></td><td><?php 
				
				echo $entry->main_id;
				
				?></td><td><?php
	
				// get worksheets feed
				$wtFeed = $gsClient->getWtFeed ($entry->main_id);
				
				if ($wtFeed) foreach ($wtFeed->entries as $wtEntry){
				
					// extract worksheet id
					$wtId = split ('/', $wtEntry->getId()->getText());
					echo $wtId[8] . "&nbsp;";
					$entry->sub_id = $wtId[8];
					
					// push to stack
					// need to clone here, since one entry contains several worksheets
					$docs[] = clone $entry;
					
				}
	
	?></td></tr>
	<?php 
		}
	?>
			</tbody>
			</table>
		
	<?php
	
	}
	
	/**
	 * Prints foot of configuration page
	 */
	public static function printFoot (){
	?>			
			<p class='submit'>
				<input type='submit' name='Submit' value="<?php _e('Save changes') ?>" />
			</p>
			
			<input type="hidden" name="action" value="update" />
			<input type="hidden" name="page_options" value="gdocs_user,gdocs_pwd,gdocs_proxy_host,gdocs_proxy_port,gdocs_proxy_user,gdocs_proxy_pwd, gdocs_cache_expiry" />
			
			
		</form>

	</div>
	<?php
	}
	
	/**
	 * Prints connection error, possibly due to proxy
	 */
	public static function printConnError (){
	
	?>
		<div class='error' id='message' style='background-color: rgb(255, 170, 150);'><p><strong><?php _e("A connection error has occurred. Are you behind a proxy?");  ?></strong></p></div>
	<?php
	
	}
	
	/**
	 * Prints login error (missing login credentials)
	 */
	public static function printNoLoginError (){
	
	?>
		<div class='error' id='message' style='background-color: rgb(255, 170, 150);'><p><strong><?php _e("Please enter your username and password."); ?></strong></p></div>
	<?php
	
	}
	
	/**
	 * Prints login error (wrong login credentials)
	 */
	public static function printWrongLoginError (){
	?>
		<div class='error' id='message' style='background-color: rgb(255, 170, 150);'><p><strong><?php _e("The plugin was unable to login to the Google service. Did you give us the wrong password/username?") ?></strong></p></div>
	<?php
	
	}
	
	/**
	 * Prints general error (means I don't know what is wrong)
	 */
	public static function printError (){
	?>
		<div class='error' id='message' style='background-color: rgb(255, 170, 150);'><p><strong><?php _e("A connection error has occurred. Perhaps you should have some coffee?") ?></strong></p></div>
	<?php
	
	}
	
	/**
	 * Prints a postbox in the edit-post / edit-page page
	 * Lists all Google documents and Google Spreadsheets
	 * Lets user add shortcode tag to post by clicking
	 */
	public static function printHelper (){
	
		$results = GDB::read ();
	
	?>
		<!-- Begin G Docs Helper -->
		<style>
			div#gdocs_helper span{
				display:block;
				float:left;
				background:#f0f0ee;
				border:solid 1px;
				color:#333;
				cursor:pointer;
				border-color:#ccc #999 #999 #ccc;
				margin:3px;
				padding:3px;
			}
			
			div#gdocs_helper img{
				float: right;
				border: 0 none;
			}
		</style>
		<div id='gdocs_helper' class='postbox closed'>
			<h3><img id='gdocs_helper_ajax' src='<?php echo get_bloginfo ('url') . "/wp-content/plugins/gdocs/inc/ajax-loader.gif" ?>' style="display: none;" />Google Documents/Spreadsheets</h3>			
			<div class='inside'>
				<p>(<a href="#" onclick="javascript: GDocs.updateList(); return false;">Update list</a>)</p><?php
			
			foreach ($results as $row){
				// <a href='#' onclick="javascript: GDocs.ring('MAIN_ID+SUB_ID', 'TYPE', 'TITLE'); return false;" id='MAIN_ID+SUB_ID'>
				printf ("<span><a href='#' onclick=\"javascript: GDocs.ring ('%s+%s', '%s', '%s'); return false;\" id='%s+%s'>%s</a></span>", $row->main_id, $row->sub_id, $row->type, $row->title, $row->main_id, $row->sub_id, $row->title);
			}
			
			?></div>
			<div style="clear:both"></div>
		</div>
		<!-- End G Docs helper -->
	<?php
	}
	
	/**
	 * Formats HTML to display spreadsheet content in a table
	 * @param $feed list feed
	 * @param $st_id spreadsheet id
	 * @param $style predefined stylesheet
	 */
	public static function printStTbl ($feed, $st_id, $wt_id, $style = NULL, $headers = NULL){
		
		// convert to spreadsheet list feed object
		$feed = new Zend_Gdata_Spreadsheets_ListFeed ($feed->getDom ());
		
		/*
		 * class=$st_id to identify with a certain spreadsheet
		 * id=$st_id $wt_id to make this worksheet unique
		 * class=gdocs allows global styles to be set across all Google Docs/Spreadsheets
		 * class=$style to associate this table with a predefined stylesheet
		 */
		$html = "<table class='gdocs gdocs_{$st_id} {$style}' id='gdocs_{$st_id}_{$wt_id}'>\r\n";
		
		// if headers are specified
		if (isset ($headers) || $feed->entries[0]){
			
			// start <thead>
			$html .= "\t<thead>\r\n";
			$html .= "\t\t<tr class='row_0'>\r\n\t\t\t";
				
			$k = 0;
			
			if (isset ($headers)){
			
				$colHeads = preg_split ("/,\s+/", $headers);
				
				// get all the headers specified by user
				foreach ($colHeads as $colHead){
					$html .= "<th class='col_{$k}'>" . $colHead . "</th>";
					$k++;
				}
			
			}
				
			if ($feed->entries[0]){
				
				// extract column headings
				$firstRow = $feed->entries[0]->getCustom ();
				
				// if  user did not specify all, get rest from list feed
				while ($colHead = $firstRow [$k]){
					$html .= "<th class='col_{$k}'>" . $colHead->getColumnName () . "</th>";
					$k++;
				}
				
				
			}
			
			// end <thead>
			$html .= "\r\n\t\t</tr>\r\n";
			$html .= "\t</thead>\r\n";
			
		}
		
		$html .= "\t<tbody>\r\n";
	
		// for every row
		$i = 1;
		foreach ($feed->entries as $entry){
		
			// start table row
			$html .= "\t\t<tr class='row_{$i}'>\r\n\t\t\t";
			
			// get all the cells in this row
			$cells = $entry->getCustom ();
			
			// for every cell, display the contents
			$j = 0;
			foreach ($cells as $cell){
				$html .= "<td class='col_{$j}'>" . $cell->getText () . "</td>";
				$j++;
			}
			
			// end table row
			$html .= "\r\n\t\t</tr>\r\n";
			$i++;
			
		}
		
		$html .= "\t</tbody>\r\n";		
		$html .= "</table>\r\n";
		
		return $html;
	
	}
	
	/**
	 * Prints stylesheet <link>
	 */
	public static function printStylesheet ($style){
	
		if (in_array ($style, self::$stylesheets)) return "";
		self::$stylesheets[] = $style;
	
		if (file_exists (dirname(__FILE__) . "/../styles/{$style}.css")){
			$path = get_bloginfo ('url') . "/wp-content/plugins/gdocs/styles/{$style}.css";
		}else {
			$path = get_bloginfo ('url') . "/wp-content/plugins/gdocs/styles/{$style}/{$style}.css";
		}
		
		return "<link rel='stylesheet' href='{$path}' type='text/css' />\r\n";
	
	}
	
	/**#@-*/

}
?>
