<?php
/**
 * Feed class, GDocs Wordpress plugin
 *
 * Handles feed iteration and parsing
 *
 * @author Lim Jiunn Haur <fisherman.jiang@broken-watch.info>
 * @copyright Copyright (c) 2008, Lim Jiunn Haur
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * @package gdocs
 * @since 0.5
 */
 
/**
 * GFeed class
 *
 * Implements Iterator from SPL, which makes objects of this class enumerable
 * Before returning current element, all necessary data is extracted and formatted
 * This hides the parsing details from whatever loops that use this class
 * @subpackage inc
 */
class GFeed implements Iterator{

	/**
	 * Feed entries
	 * @access private
	 * @var mixed
	 */
	private $entries;
	
	/**
	 * Iteration pointer
	 * @access private
	 * @var integer
	 */
	private $curr = 0;
	
	/**
	 * Feed type (either 'doc' or 'st')
	 * @access private
	 * @var string
	 */
	private $type;
	
	/**
	 * Class constructor
	 * @method GFeed GFeed ($feed, $type) creates and initializes new GFeed object
	 * @param $feed raw feed returned by Google
	 * @param $type gdoc type (either 'doc' or 'st')
	 * @return GFeed object
	 * @access public
	 */
	public function __construct ($feed, $type){
		if (!$feed) throw new Exception ();
		
		$this->entries = $feed->entries;
		$this->type = $type;
	}
	
	/**
	 * Iterator function: access current element
	 *
	 * Accesses current element from array
	 * Extracts and parses data
	 * Returns relevant data in a nice array
	 * @return array array of entry attributes
	 * @access public
	 */
	public function current (){
		$entry = $this->entries[$this->curr];
		$title = $entry->getTitle()->getText();
		preg_match ('/^.+%3A(.+)$/', $entry->getId()->getText(), $matches);
		$id = $matches[1];
		$type = $this->type;
		return (object) array ('title' => $title, 'main_id' => $id, 'type' => $type);
	}
	
	/**
	 * Iterator function: move to next element
	 * @access public
	 */
	public function next (){
		$this->curr += 1;
	}
	
	/** 
	 * Iterator function: get the current key
	 * @return integer $curr pointer of current element (just an array index)
	 * @access public
	 */
	public function key (){
		return $this->curr;
	}
	
	/**
	 * Iterator function: reset pointer
	 * @access public
	 */
	public function rewind (){
		$this->curr = 0;
	}
	
	/**
	 * Iterator function: test if end-of-iteration
	 * @return boolean false if end is reached, true is still more to loop
	 * @access public
	 */
	public function valid (){
		return $this->entries[$this->curr];			
	}

}
?>
